@@ -16,12 +16,14 @@
 #'
 check_java_path <- function(javastics) {
   if (!file.exists(javastics)) {
-    stop("The JavaStics folder doesn't exist : ", javastics)
+    stop("The JavaSTICS folder doesn't exist : ", javastics)
   }
 
   # checking if it's a JavaSTICS root directory
-  if (!file.exists(file.path(javastics, "JavaStics.exe")) &&
-    !file.exists(file.path(javastics, "JavaStics.jar"))) {
+  if (
+    !file.exists(file.path(javastics, "JavaStics.exe")) &&
+      !file.exists(file.path(javastics, "JavaStics.jar"))
+  ) {
     stop("This directory is not a JavaSTICS one: ", javastics)
   }
 }
