@@ -1,13 +1,16 @@
-check_param_names <- function(param_names, ref_names, pattern_tag = "",
-                              err_stop = TRUE) {
-
+check_param_names <- function(
+    param_names,
+    ref_names,
+    pattern_tag = "",
+    err_stop = TRUE) {
   # Checking parameter names from param_table against xml ones
   # param_names <- unique(gsub(pattern =
   # paste0("\\_(",pattern_tag,"){0,1}[1-9]+"), x = tolower(param_names), ""))
   param_names <- unique(
     gsub(
       pattern = paste0("\\_(", pattern_tag, "){0,1}[1-9]+"),
-      x = param_names, ""
+      x = param_names,
+      ""
     )
   )
 
