@@ -30,45 +30,49 @@
 #'
 #' download_usm_xl()
 #'
-#'
 #' @export
 #'
 
-download_usm_xl <- function(file = NULL,
-                            out_dir = tempdir(),
-                            stics_version = "latest",
-                            overwrite = FALSE,
-                            verbose = FALSE,
-                            xl_name = lifecycle::deprecated(),
-                            version_name = lifecycle::deprecated(),
-                            dest_dir = lifecycle::deprecated(),
-                            ...) {
+download_usm_xl <- function(
+    file = NULL,
+    out_dir = tempdir(),
+    stics_version = "latest",
+    overwrite = FALSE,
+    verbose = FALSE,
+    xl_name = lifecycle::deprecated(),
+    version_name = lifecycle::deprecated(),
+    dest_dir = lifecycle::deprecated(),
+    ...) {
   if (lifecycle::is_present(xl_name)) {
-    lifecycle::deprecate_warn("1.0.0",
-                              "download_usm_xl(xl_name)",
-                              "download_usm_xl(file)")
+    lifecycle::deprecate_warn(
+      "1.0.0",
+      "download_usm_xl(xl_name)",
+      "download_usm_xl(file)"
+    )
   } else {
     xl_name <- file # to remove when we update inside the function
   }
   if (lifecycle::is_present(version_name)) {
-    lifecycle::deprecate_warn("1.0.0",
-                              "download_usm_xl(version_name)",
-                              "download_usm_xl(stics_version)")
+    lifecycle::deprecate_warn(
+      "1.0.0",
+      "download_usm_xl(version_name)",
+      "download_usm_xl(stics_version)"
+    )
   } else {
     version_name <- stics_version # to remove when we update inside the function
   }
   if (lifecycle::is_present(dest_dir)) {
-    lifecycle::deprecate_warn("1.0.0",
-                              "download_usm_xl(dest_dir)",
-                              "download_usm_xl(out_dir)")
+    lifecycle::deprecate_warn(
+      "1.0.0",
+      "download_usm_xl(dest_dir)",
+      "download_usm_xl(out_dir)"
+    )
   } else {
     dest_dir <- out_dir # to remove when we update inside the function
   }
 
-
   args <- list(...)
 
-
   xl_patt <- "^inputs\\_.*(example|USMs)\\.(xls|xlsx)$"
   file_type <- "xl"
 
@@ -81,8 +85,10 @@ download_usm_xl <- function(file = NULL,
     xl_name <- xl_patt
   }
 
-  xl_dir <- get_examples_path(file_type = "xl",
-                              stics_version = version_name)
+  xl_dir <- get_examples_path(
+    file_type = "xl",
+    stics_version = version_name
+  )
 
   files_list <- list.files(xl_dir, pattern = xl_patt)
 
@@ -100,7 +106,9 @@ download_usm_xl <- function(file = NULL,
   exist_files <- file.exists(dest_list)
   if (!overwrite && any(exist_files)) {
     warning(paste(
-      files_list[exist_files], "already exists in ", dest_dir,
+      files_list[exist_files],
+      "already exists in ",
+      dest_dir,
       "\nConsider to set overwrite = TRUE to overwrite (it | them )"
     ))
     # filtering existing files, not copied if overwrite == FALSE
@@ -111,23 +119,27 @@ download_usm_xl <- function(file = NULL,
   success <- file.copy(from = src_list, to = dest_dir, overwrite = overwrite)
 
   if (any(success)) {
-    if (verbose)
-      message(paste(files_list[success],
-                    " has been copied in directory ",
-                    dest_dir))
+    if (verbose) {
+      message(paste(
+        files_list[success],
+        " has been copied in directory ",
+        dest_dir
+      ))
+    }
     dest_list <- dest_list[success]
   }
 
-  if (!all(success))
-    warning("Error copying files:\n", paste(src_list[!success],
-                                            collapse = "\n"))
-
+  if (!all(success)) {
+    warning(
+      "Error copying files:\n",
+      paste(src_list[!success], collapse = "\n")
+    )
+  }
 
   return(invisible(dest_list))
 }
 
 
-
 #' @title Downloading a CSV usms data file example into a directory
 #'
 #' @description The file is an example that can be used for generating JavaSTICS
@@ -156,37 +168,43 @@ download_usm_xl <- function(file = NULL,
 #' @export
 #'
 
-download_usm_csv <- function(file = NULL,
-                             out_dir = tempdir(),
-                             stics_version = "latest",
-                             overwrite = FALSE,
-                             verbose = FALSE,
-                             csv_name = lifecycle::deprecated(),
-                             version_name = lifecycle::deprecated(),
-                             dest_dir = lifecycle::deprecated()) {
+download_usm_csv <- function(
+    file = NULL,
+    out_dir = tempdir(),
+    stics_version = "latest",
+    overwrite = FALSE,
+    verbose = FALSE,
+    csv_name = lifecycle::deprecated(),
+    version_name = lifecycle::deprecated(),
+    dest_dir = lifecycle::deprecated()) {
   if (lifecycle::is_present(csv_name)) {
-    lifecycle::deprecate_warn("1.0.0",
-                              "download_usm_csv(csv_name)",
-                              "download_usm_csv(file)")
+    lifecycle::deprecate_warn(
+      "1.0.0",
+      "download_usm_csv(csv_name)",
+      "download_usm_csv(file)"
+    )
   } else {
     csv_name <- file # to remove when we update inside the function
   }
   if (lifecycle::is_present(version_name)) {
-    lifecycle::deprecate_warn("1.0.0",
-                              "download_usm_csv(version_name)",
-                              "download_usm_csv(stics_version)")
+    lifecycle::deprecate_warn(
+      "1.0.0",
+      "download_usm_csv(version_name)",
+      "download_usm_csv(stics_version)"
+    )
   } else {
     version_name <- stics_version # to remove when we update inside the function
   }
   if (lifecycle::is_present(dest_dir)) {
-    lifecycle::deprecate_warn("1.0.0",
-                              "download_usm_csv(dest_dir)",
-                              "download_usm_csv(out_dir)")
+    lifecycle::deprecate_warn(
+      "1.0.0",
+      "download_usm_csv(dest_dir)",
+      "download_usm_csv(out_dir)"
+    )
   } else {
     dest_dir <- out_dir # to remove when we update inside the function
   }
 
-
   download_usm_xl(
     file = csv_name,
     out_dir = dest_dir,
