@@ -58,37 +58,44 @@
 #' ini_param_df <- read_excel(xl_path, sheet = "Ini")
 #' gen_ini_xml(
 #'   out_dir = tempdir(),
-#'   param_df = ini_param_df[1:2,]
+#'   param_df = ini_param_df[1:2, ]
 #' )
 #'
 #' @export
 #'
-gen_ini_xml <- function(param_df,
-                        file = NULL,
-                        out_dir,
-                        crop_tag = "Crop",
-                        stics_version = "latest",
-                        ini_in_file = lifecycle::deprecated(),
-                        param_table = lifecycle::deprecated(),
-                        out_path = lifecycle::deprecated()) {
+gen_ini_xml <- function(
+    param_df,
+    file = NULL,
+    out_dir,
+    crop_tag = "Crop",
+    stics_version = "latest",
+    ini_in_file = lifecycle::deprecated(),
+    param_table = lifecycle::deprecated(),
+    out_path = lifecycle::deprecated()) {
   if (lifecycle::is_present(ini_in_file)) {
-    lifecycle::deprecate_warn("1.0.0",
-                              "gen_ini_xml(ini_in_file)",
-                              "gen_ini_xml(file)")
+    lifecycle::deprecate_warn(
+      "1.0.0",
+      "gen_ini_xml(ini_in_file)",
+      "gen_ini_xml(file)"
+    )
   } else {
     ini_in_file <- file # to remove when we update inside the function
   }
   if (lifecycle::is_present(param_table)) {
-    lifecycle::deprecate_warn("1.0.0",
-                              "gen_ini_xml(param_table)",
-                              "gen_ini_xml(param_df)")
+    lifecycle::deprecate_warn(
+      "1.0.0",
+      "gen_ini_xml(param_table)",
+      "gen_ini_xml(param_df)"
+    )
   } else {
     param_table <- param_df # to remove when we update inside the function
   }
   if (lifecycle::is_present(out_path)) {
-    lifecycle::deprecate_warn("1.0.0",
-                              "gen_ini_xml(out_path)",
-                              "gen_ini_xml(out_dir)")
+    lifecycle::deprecate_warn(
+      "1.0.0",
+      "gen_ini_xml(out_path)",
+      "gen_ini_xml(out_dir)"
+    )
   } else {
     out_path <- out_dir # to remove when we update inside the function
   }
@@ -125,10 +132,12 @@ gen_ini_xml <- function(param_df,
   out_idx <- unlist(lapply(xml_docs, base::is.null))
 
   if (any(out_idx)) {
-    message("\nErrors have been detected while trying to replace",
-            "parameters values in xml documents",
-            paste(sum(!out_idx), "files have been generated !"),
-            appendLF = TRUE)
+    message(
+      "\nErrors have been detected while trying to replace",
+      "parameters values in xml documents",
+      paste(sum(!out_idx), "files have been generated !"),
+      appendLF = TRUE
+    )
     # selecting available documents to produce
     xml_docs <- xml_docs[out_idx]
   }
@@ -138,7 +147,6 @@ gen_ini_xml <- function(param_df,
     return(invisible())
   }
 
-
   # Checking if out_path exists
   if (!dir.exists(out_path)) {
     stop(paste("The directory does not exist", out_path))
@@ -166,6 +174,7 @@ gen_ini_xml <- function(param_df,
     delete(xml_docs[[f]])
   }
 
-  if (!base::is.null(xml_doc_tmpl) && inherits(xml_doc_tmpl, "xml_document"))
+  if (!base::is.null(xml_doc_tmpl) && inherits(xml_doc_tmpl, "xml_document")) {
     delete(xml_doc_tmpl)
+  }
 }
