@@ -32,20 +32,21 @@
 #' param_names <- get_param_names_xml(xml_files_list)
 #'
 #' param_names <- get_param_names_xml(xml_files_list,
-#'                                    param_name = c("al", "albedo"))
+#'   param_name = c("al", "albedo")
+#' )
 #' }
 #'
 #' @keywords internal
 #'
 #' @noRd
 #'
-get_param_names_xml <- function(xml_file,
-                                name = NULL,
-                                bounds = TRUE,
-                                output = "data.frame",
-                                combine = TRUE,
-                                exact = FALSE) {
-
+get_param_names_xml <- function(
+    xml_file,
+    name = NULL,
+    bounds = TRUE,
+    output = "data.frame",
+    combine = TRUE,
+    exact = FALSE) {
   # Switch for transformations to data.frame format
   df_out <- output == "data.frame"
   df_comb <- df_out & combine
@@ -89,7 +90,6 @@ get_param_names_xml <- function(xml_file,
   xml_doc <- xmldocument(xml_file)
   param_names <- get_param_names(xml_object = xml_doc)
 
-
   # Search based on names or a substring of parameters names
   # exact match with exact == TRUE
   if (!base::is.null(name)) {
@@ -102,7 +102,6 @@ get_param_names_xml <- function(xml_file,
     return(NULL)
   }
 
-
   # Getting optional bounds
   if (bounds) {
     param_bounds <- get_param_bounds(
@@ -125,10 +124,11 @@ get_param_names_xml <- function(xml_file,
     }
   } else {
     if (bounds) {
-      param_names <- list(list(file = base::basename(xml_file),
-                               name = param_bounds))
+      param_names <- list(list(
+        file = base::basename(xml_file),
+        name = param_bounds
+      ))
     } else {
-
       # To a named list
       names(param_names) <- base::basename(xml_file)
     }
