@@ -63,30 +63,34 @@
 #' # Get parameters for a specific plant
 #' get_param_txt(workspace = path, plant_id = 1)
 #' get_param_txt(workspace = path, param = "durvieF", plant_id = 1)
-#' get_param_txt(workspace = path, param = "durvieF", plant_id = 1,
-#' variety = varieties)
+#' get_param_txt(
+#'   workspace = path, param = "durvieF", plant_id = 1,
+#'   variety = varieties
+#' )
 #'
 #' # Get parameters for specific interventions or soil layers
-#' get_param_txt(workspace = path, param = "amount", value_id = c(1,3))
-#' get_param_txt(workspace = path, param = "Hinitf", value_id = c(1,3))
-#' get_param_txt(workspace = path, param = "epc", value_id = c(1,3))
+#' get_param_txt(workspace = path, param = "amount", value_id = c(1, 3))
+#' get_param_txt(workspace = path, param = "Hinitf", value_id = c(1, 3))
+#' get_param_txt(workspace = path, param = "epc", value_id = c(1, 3))
 #'
 #' @export
 #'
-get_param_txt <- function(workspace,
-                          param = NULL,
-                          plant_id = NULL,
-                          variety = NULL,
-                          value_id = NULL,
-                          exact = FALSE,
-                          stics_version = "latest",
-                          dirpath = lifecycle::deprecated(),
-                          ...) {
-
+get_param_txt <- function(
+  workspace,
+  param = NULL,
+  plant_id = NULL,
+  variety = NULL,
+  value_id = NULL,
+  exact = FALSE,
+  stics_version = "latest",
+  dirpath = lifecycle::deprecated(),
+  ...
+) {
   # dirpath
   if (lifecycle::is_present(dirpath)) {
     lifecycle::deprecate_warn(
-      "1.0.0", "get_param_txt(dirpath)",
+      "1.0.0",
+      "get_param_txt(dirpath)",
       "get_param_txt(workspace)"
     )
   } else {
@@ -95,47 +99,64 @@ get_param_txt <- function(workspace,
 
   stics_version <- check_version_compat(stics_version = stics_version)
 
-  ini <- get_ini_txt(file.path(dirpath, "ficini.txt"),
-                     stics_version = stics_version)
+  ini <- get_ini_txt(
+    file.path(dirpath, "ficini.txt"),
+    stics_version = stics_version
+  )
 
   # specifying plant(s) to use, and checking if a given plant_id is
   # available ones
   avail_plant_id <- seq_len(ini$nbplantes)
 
-  if(is.null(plant_id)) {
+  if (is.null(plant_id)) {
     plant_id <- avail_plant_id
   } else {
-    if(!all(plant_id %in% avail_plant_id))
-      stop("Given plant id(s) (",
-           paste(plant_id, collapse = ","), ") ",
-           " do(es) not match available one(s) (",
-           paste(avail_plant_id, collapse = ","), ")")
+    if (!all(plant_id %in% avail_plant_id)) {
+      stop(
+        "Given plant id(s) (",
+        paste(plant_id, collapse = ","),
+        ") ",
+        " do(es) not match available one(s) (",
+        paste(avail_plant_id, collapse = ","),
+        ")"
+      )
+    }
   }
 
-
   general <- get_general_txt(file.path(dirpath, "tempopar.sti"))
 
-  soil <- get_soil_txt(file.path(dirpath, "param.sol"),
-                       stics_version = stics_version)
+  soil <- get_soil_txt(
+    file.path(dirpath, "param.sol"),
+    stics_version = stics_version
+  )
 
   station <- get_station_txt(file.path(dirpath, "station.txt"))
 
-  usm <- get_usm_txt(file.path(dirpath, "new_travail.usm"),
-                     plant_id = plant_id)
+  usm <- get_usm_txt(file.path(dirpath, "new_travail.usm"), plant_id = plant_id)
 
   tmp <- get_tmp_txt(file.path(dirpath, "tempoparv6.sti"))
 
-
   # add tests on option_* name existence in tmp
   # NOT IN V10
   several_fert <- several_thin <- is_pasture <- NULL
   tmp_names <- names(tmp)
-  several_fert <- ifelse("option_engrais_multiple" %in% tmp_names &&
-                           tmp$option_engrais_multiple == 1, TRUE, FALSE)
-  several_thin <- ifelse("option_thinning" %in% tmp_names &&
-                           tmp$option_thinning == 1, TRUE, FALSE)
-  is_pasture <- ifelse("option_pature" %in% tmp_names &&
-                         tmp$option_pature == 1, TRUE, FALSE)
+  several_fert <- ifelse(
+    "option_engrais_multiple" %in%
+      tmp_names &&
+      tmp$option_engrais_multiple == 1,
+    TRUE,
+    FALSE
+  )
+  several_thin <- ifelse(
+    "option_thinning" %in% tmp_names && tmp$option_thinning == 1,
+    TRUE,
+    FALSE
+  )
+  is_pasture <- ifelse(
+    "option_pature" %in% tmp_names && tmp$option_pature == 1,
+    TRUE,
+    FALSE
+  )
 
   tec <- plant <- stats::setNames(
     vector(mode = "list", length = ini$nbplantes),
@@ -155,42 +176,51 @@ get_param_txt <- function(workspace,
     tec[paste0("plant", i)] <-
       list(get_tec_txt(
         file = file.path(dirpath, paste0("fictec", i, ".txt")),
-        several_fert = several_fert, several_thin = several_thin,
+        several_fert = several_fert,
+        several_thin = several_thin,
         is_pasture = is_pasture
       ))
 
     varieties[[i]] <-
-      get_plant_txt(file = file.path(dirpath,
-                                     paste0("ficplt", i, ".txt")))$codevar
+      get_plant_txt(
+        file = file.path(
+          dirpath,
+          paste0("ficplt", i, ".txt")
+        )
+      )$codevar
 
     tec_variety <- tec[[paste0("plant", i)]]$variete
 
-    alert_msg <- paste0("Variety not found in plant file. Possible ",
-                        "varieties are: {.val {varieties}}")
+    alert_msg <- paste0(
+      "Variety not found in plant file. Possible ",
+      "varieties are: {.val {varieties}}"
+    )
 
     plant[paste0("plant", i)] <-
-      list(get_plant_txt(file.path(dirpath, paste0("ficplt", i, ".txt")),
-                         variety =
-                           if (is.null(variety[[i]])) {
-                             if (!is.null(param)) {
-                               varieties[[i]][tec_variety]
-                             } else {
-                               NULL
-                             }
-                           } else {
-                             # variety
-                             if (is.character(variety[[i]])) {
-                               variety[[i]] <- match(variety[[i]],
-                                                     varieties[[i]])
-                               if (any(is.na(variety))) {
-                                 cli::cli_alert_danger(alert_msg)
-                                 return()
-                               }
-                               varieties[[i]][variety[[i]]]
-                             } else {
-                               varieties[[i]][variety[[i]]]
-                             }
-                           }
+      list(get_plant_txt(
+        file.path(dirpath, paste0("ficplt", i, ".txt")),
+        variety = if (is.null(variety[[i]])) {
+          if (!is.null(param)) {
+            varieties[[i]][tec_variety]
+          } else {
+            NULL
+          }
+        } else {
+          # variety
+          if (is.character(variety[[i]])) {
+            variety[[i]] <- match(
+              variety[[i]],
+              varieties[[i]]
+            )
+            if (any(is.na(variety))) {
+              cli::cli_alert_danger(alert_msg)
+              return()
+            }
+            varieties[[i]][variety[[i]]]
+          } else {
+            varieties[[i]][variety[[i]]]
+          }
+        }
       ))
 
     # Fixes the current variety
@@ -198,8 +228,13 @@ get_param_txt <- function(workspace,
   }
 
   parameters <- list(
-    usm = usm, ini = ini, general = general, tec = tec,
-    plant = plant, soil = soil, station = station,
+    usm = usm,
+    ini = ini,
+    general = general,
+    tec = tec,
+    plant = plant,
+    soil = soil,
+    station = station,
     tmp = tmp
   )
 
@@ -208,26 +243,27 @@ get_param_txt <- function(workspace,
     return(parameters)
   }
 
-
   # Extracting a sublist of desired parameters, with respect to the original
   # full list structure, with or without exact search
   # using or not ids for soil layers, technical interventions (ini, soil or
   # tec parameters files)
-  parameters <- filter_param(parameters,
-                             param = param,
-                             exact = exact,
-                             value_id = value_id)
-
+  parameters <- filter_param(
+    parameters,
+    param = param,
+    exact = exact,
+    value_id = value_id
+  )
 
   return(parameters)
 }
 
 
-
-filter_param <- function(in_list,
-                         param = NULL,
-                         exact = FALSE,
-                         value_id = NULL) {
+filter_param <- function(
+  in_list,
+  param = NULL,
+  exact = FALSE,
+  value_id = NULL
+) {
   out_list <- list()
   names_vec <- names(in_list)
 
@@ -235,8 +271,12 @@ filter_param <- function(in_list,
     name <- names_vec[[i]]
 
     if (is.list(in_list[[name]])) {
-      tmp <- filter_param(in_list[[name]], param = param,
-                          exact = exact, value_id = value_id)
+      tmp <- filter_param(
+        in_list[[name]],
+        param = param,
+        exact = exact,
+        value_id = value_id
+      )
 
       if (length(tmp) > 0) out_list[[name]] <- tmp
       next
@@ -258,15 +298,19 @@ filter_param <- function(in_list,
     if (any(idx)) {
       out_list[[name]] <- in_list[[name]]
 
-      if(is.null(value_id)) next
+      if (is.null(value_id)) next
 
       # checking if given ids exist in parameter values
       avail_ids <- seq_len(length(out_list[[name]]))
-      if (!all(value_id %in% avail_ids))
-        stop("Given ids (",
-             paste(value_id, collapse = ", "),
-             ") are not all available in existing ids (",
-             paste(avail_ids, collapse = ", "),")")
+      if (!all(value_id %in% avail_ids)) {
+        stop(
+          "Given ids (",
+          paste(value_id, collapse = ", "),
+          ") are not all available in existing ids (",
+          paste(avail_ids, collapse = ", "),
+          ")"
+        )
+      }
 
       # sub scripting values
       out_list[[name]] <- out_list[[name]][value_id]
@@ -313,7 +357,7 @@ filter_param <- function(in_list,
 #'
 #' @examples
 #' \dontrun{
-#' # Read the initialisation file (ficini.txt):
+#' # Read the initialization file (ficini.txt):
 #' library(SticsRFiles)
 #' path <- file.path(get_examples_path(file_type = "txt"), "ficini.txt")
 #' get_ini_txt(path)
@@ -321,8 +365,10 @@ filter_param <- function(in_list,
 #' # Read the tec file directly:
 #'
 #' # First, get the parameters from the tmp file:
-#' tmp <- get_tmp_txt(file = file.path(get_examples_path(file_type = "txt"),
-#'                                     "tempoparv6.sti"))
+#' tmp <- get_tmp_txt(file = file.path(
+#'   get_examples_path(file_type = "txt"),
+#'   "tempoparv6.sti"
+#' ))
 #' several_fert <- ifelse(tmp$option_engrais_multiple == 1, TRUE, FALSE)
 #' several_thin <- ifelse(tmp$option_thinning == 1, TRUE, FALSE)
 #' is_pasture <- ifelse(tmp$option_pature == 1, TRUE, FALSE)
@@ -337,14 +383,16 @@ filter_param <- function(in_list,
 #'
 #' @rdname get_param_txt
 #' @export
-get_ini_txt <- function(file = "ficini.txt",
-                        stics_version,
-                        filepath = lifecycle::deprecated()) {
-
+get_ini_txt <- function(
+  file = "ficini.txt",
+  stics_version,
+  filepath = lifecycle::deprecated()
+) {
   # filepath
   if (lifecycle::is_present(filepath)) {
     lifecycle::deprecate_warn(
-      "1.0.0", "get_ini_txt(filepath)",
+      "1.0.0",
+      "get_ini_txt(filepath)",
       "get_ini_txt(file)"
     )
   } else {
@@ -353,8 +401,9 @@ get_ini_txt <- function(file = "ficini.txt",
 
   stics_version <- check_version_compat(stics_version = stics_version)
 
-  if (!file.exists(filepath))
+  if (!file.exists(filepath)) {
     stop(filepath, ": does not exist !")
+  }
 
   params <- readLines(filepath)
   ini <- list()
@@ -362,15 +411,16 @@ get_ini_txt <- function(file = "ficini.txt",
   ini$nbplantes <- params[[2]]
   ini$plant <- list()
 
-
   stics_version_num <- get_version_num(stics_version = stics_version)
 
   if (stics_version_num < 10) {
-
-    if (length(params) > 48)
-      stop("The used STICS version ",
-           stics_version_num,
-           " does not correspond to the file content (STICS version >= 10)")
+    if (length(params) > 48) {
+      stop(
+        "The used STICS version ",
+        stics_version_num,
+        " does not correspond to the file content (STICS version >= 10)"
+      )
+    }
 
     ini$plant$plant1 <- list(
       stade0 = params[[4]],
@@ -398,11 +448,13 @@ get_ini_txt <- function(file = "ficini.txt",
     ini$NO3init <- params[[26]]
     ini$NH4init <- params[[28]]
   } else {
-
-    if (length(params) < 48)
-      stop("The used STICS version ",
-           stics_version_num,
-           " does not correspond to the file content (STICS version < 10)")
+    if (length(params) < 48) {
+      stop(
+        "The used STICS version ",
+        stics_version_num,
+        " does not correspond to the file content (STICS version < 10)"
+      )
+    }
 
     ini$plant$plant1 <- list(
       stade0 = params[[4]],
@@ -452,13 +504,15 @@ get_ini_txt <- function(file = "ficini.txt",
 
 #' @rdname get_param_txt
 #' @export
-get_general_txt <- function(file = "tempopar.sti",
-                            filepath = lifecycle::deprecated()) {
-
+get_general_txt <- function(
+  file = "tempopar.sti",
+  filepath = lifecycle::deprecated()
+) {
   # filepath
   if (lifecycle::is_present(filepath)) {
     lifecycle::deprecate_warn(
-      "1.0.0", "get_general_txt(filepath)",
+      "1.0.0",
+      "get_general_txt(filepath)",
       "get_general_txt(file)"
     )
   } else {
@@ -471,13 +525,15 @@ get_general_txt <- function(file = "tempopar.sti",
 
 #' @rdname get_param_txt
 #' @export
-get_tmp_txt <- function(file = "tempoparv6.sti",
-                        filepath = lifecycle::deprecated()) {
-
+get_tmp_txt <- function(
+  file = "tempoparv6.sti",
+  filepath = lifecycle::deprecated()
+) {
   # filepath
   if (lifecycle::is_present(filepath)) {
     lifecycle::deprecate_warn(
-      "1.0.0", "get_tmp_txt(filepath)",
+      "1.0.0",
+      "get_tmp_txt(filepath)",
       "get_tmp_txt(file)"
     )
   } else {
@@ -489,13 +545,16 @@ get_tmp_txt <- function(file = "tempoparv6.sti",
 
 #' @rdname get_param_txt
 #' @export
-get_plant_txt <- function(file = "ficplt1.txt", variety = NULL,
-                          filepath = lifecycle::deprecated()) {
-
+get_plant_txt <- function(
+  file = "ficplt1.txt",
+  variety = NULL,
+  filepath = lifecycle::deprecated()
+) {
   # filepath
   if (lifecycle::is_present(filepath)) {
     lifecycle::deprecate_warn(
-      "1.0.0", "get_plant_txt(filepath)",
+      "1.0.0",
+      "get_plant_txt(filepath)",
       "get_plant_txt(file)"
     )
   } else {
@@ -535,31 +594,31 @@ get_plant_txt <- function(file = "ficplt1.txt", variety = NULL,
 }
 
 
-
-
 #' @rdname get_param_txt
 #' @export
-get_tec_txt <- function(file = "fictec1.txt",
-                        stics_version = "latest",
-                        several_fert = NULL,
-                        several_thin = NULL,
-                        is_pasture = NULL,
-                        filepath = lifecycle::deprecated(),
-                        ...) {
-
+get_tec_txt <- function(
+  file = "fictec1.txt",
+  stics_version = "latest",
+  several_fert = NULL,
+  several_thin = NULL,
+  is_pasture = NULL,
+  filepath = lifecycle::deprecated(),
+  ...
+) {
   # filepath
   if (lifecycle::is_present(filepath)) {
     lifecycle::deprecate_warn(
-      "1.0.0", "get_tec_txt(filepath)",
+      "1.0.0",
+      "get_tec_txt(filepath)",
       "get_tec_txt(file)"
     )
   } else {
     filepath <- file # to remove when we update inside the function
   }
 
-  if (!file.exists(filepath))
+  if (!file.exists(filepath)) {
     stop(filepath, ": does not exist !")
-
+  }
 
   # TODO: add dot args management
   # Future-proofing the function. We can add arguments now without
@@ -574,7 +633,6 @@ get_tec_txt <- function(file = "fictec1.txt",
   params <- par_lines[!ids_val]
   values <- par_lines[ids_val]
 
-
   # Early return here for version >= 10.0
   # get_tec_txt_ is not fully generic for the moment!
   if (get_version_num(stics_version = stics_version) >= 10) {
@@ -623,7 +681,6 @@ get_tec_txt <- function(file = "fictec1.txt",
   pval <- val(values = values)
   itk$nap <- pval$val
 
-
   if (itk$nap > 0) {
     for (i in 1:itk$nap) {
       pval <- val(pval, values)
@@ -649,7 +706,6 @@ get_tec_txt <- function(file = "fictec1.txt",
     itk$engrais <- pval$val
   }
 
-
   for (i in 1:4) {
     pval <- val(pval, values)
     pname <- parname(pval$index, params, -1)
@@ -696,7 +752,6 @@ get_tec_txt <- function(file = "fictec1.txt",
     }
   }
 
-
   for (i in 1:19) {
     pval <- val(pval, values)
     pname <- parname(pval$index, params, -1)
@@ -709,7 +764,6 @@ get_tec_txt <- function(file = "fictec1.txt",
     itk$lecfauche <- TRUE
   }
 
-
   for (i in 1:2) {
     pval <- val(pval, values)
     pname <- parname(pval$index, params, -1)
@@ -759,7 +813,6 @@ get_tec_txt <- function(file = "fictec1.txt",
     itk$nbcoupe <- nbcoupe3
   }
 
-
   for (i in 1:11) {
     pval <- val(pval, values)
     pname <- parname(pval$index, params, -1)
@@ -786,7 +839,6 @@ get_tec_txt <- function(file = "fictec1.txt",
     itk$nbinfloecl <- pval$val
   }
 
-
   for (i in 1:30) {
     pval <- val(pval, values)
     pname <- parname(pval$index, params, -1)
@@ -811,7 +863,6 @@ parname <- function(index, params, idx = NULL) {
 }
 
 val <- function(pval = list(index = 1, val = NA), values) {
-
   if (pval$index == length(values)) {
     return()
   }
@@ -837,8 +888,13 @@ get_tec_txt_ <- function(params, values) {
   num_op <- 0
   nb_interventions <- 0
   intervention_type <- c(
-    "nbjres", "nbjtrav", "nap", "napN",
-    "nbcoupe", "nbcoupe", "nb_eclair"
+    "nbjres",
+    "nbjtrav",
+    "nap",
+    "napN",
+    "nbcoupe",
+    "nbcoupe",
+    "nb_eclair"
   )
 
   v <- list()
@@ -869,9 +925,7 @@ get_tec_txt_ <- function(params, values) {
 
     # multiple parameters
     if (all(param == parname(pval$index, params, -2))) {
-      value <- as.data.frame(as.list(value),
-                             stringsAsFactors = FALSE
-      )
+      value <- as.data.frame(as.list(value), stringsAsFactors = FALSE)
       names(value) <- param
       v <- rbind(v, value)
 
@@ -881,9 +935,7 @@ get_tec_txt_ <- function(params, values) {
       }
       next
     } else {
-      v <- as.data.frame(as.list(value),
-                         stringsAsFactors = FALSE
-      )
+      v <- as.data.frame(as.list(value), stringsAsFactors = FALSE)
       names(v) <- param
     }
 
@@ -897,14 +949,16 @@ get_tec_txt_ <- function(params, values) {
 
 #' @rdname get_param_txt
 #' @export
-get_soil_txt <- function(file = "param.sol",
-                         stics_version,
-                         filepath = lifecycle::deprecated()) {
-
+get_soil_txt <- function(
+  file = "param.sol",
+  stics_version,
+  filepath = lifecycle::deprecated()
+) {
   # filepath
   if (lifecycle::is_present(filepath)) {
     lifecycle::deprecate_warn(
-      "1.0.0", "get_soil_txt(filepath)",
+      "1.0.0",
+      "get_soil_txt(filepath)",
       "get_soil_txt(file)"
     )
   } else {
@@ -913,8 +967,9 @@ get_soil_txt <- function(file = "param.sol",
 
   stics_version <- check_version_compat(stics_version = stics_version)
 
-  if (!file.exists(filepath))
+  if (!file.exists(filepath)) {
     stop(filepath, ": does not exist !")
+  }
 
   params <- readLines(filepath, warn = FALSE)
   soil <- vector(mode = "list", length = 0)
@@ -930,35 +985,79 @@ get_soil_txt <- function(file = "param.sol",
 
   if (get_version_num(stics_version = stics_version) < 10) {
     par_vec <- c(
-      "numsol", "typsol", "argi", "Norg", "profhum", "calc", "pH",
-      "concseuil", "albedo", "q0", "ruisolnu", "obstarac", "pluiebat",
-      "mulchbat", "zesx", "cfes", "z0solnu", "CsurNsol", "penterui"
+      "numsol",
+      "typsol",
+      "argi",
+      "Norg",
+      "profhum",
+      "calc",
+      "pH",
+      "concseuil",
+      "albedo",
+      "q0",
+      "ruisolnu",
+      "obstarac",
+      "pluiebat",
+      "mulchbat",
+      "zesx",
+      "cfes",
+      "z0solnu",
+      "CsurNsol",
+      "penterui"
     )
   } else {
     par_vec <- c(
-      "numsol", "typsol", "argi", "Norg", "profhum", "calc", "pH",
-      "concseuil", "albedo", "q0", "ruisolnu", "obstarac", "pluiebat",
-      "mulchbat", "zesx", "cfes", "z0solnu", "CsurNsol", "finert", "penterui"
+      "numsol",
+      "typsol",
+      "argi",
+      "Norg",
+      "profhum",
+      "calc",
+      "pH",
+      "concseuil",
+      "albedo",
+      "q0",
+      "ruisolnu",
+      "obstarac",
+      "pluiebat",
+      "mulchbat",
+      "zesx",
+      "cfes",
+      "z0solnu",
+      "CsurNsol",
+      "finert",
+      "penterui"
     )
   }
 
   ret_val <- val()
   soil[par_vec] <- ret_val$vec
 
-
   ret_val <- val(ret_val$index)
 
   soil[c(
-    "numsol", "codecailloux", "codemacropor", "codefente",
-    "codrainage", "coderemontcap", "codenitrif", "codedenit"
+    "numsol",
+    "codecailloux",
+    "codemacropor",
+    "codefente",
+    "codrainage",
+    "coderemontcap",
+    "codenitrif",
+    "codedenit"
   )] <- ret_val$vec
 
   ret_val <- val(ret_val$index)
 
-
   soil[c(
-    "numsol", "profimper", "ecartdrain", "ksol", "profdrain",
-    "capiljour", "humcapil", "profdenit", "vpotdenit"
+    "numsol",
+    "profimper",
+    "ecartdrain",
+    "ksol",
+    "profdrain",
+    "capiljour",
+    "humcapil",
+    "profdenit",
+    "vpotdenit"
   )] <- ret_val$vec
 
   vec <- matrix(data = NA, nrow = 9, ncol = 5)
@@ -969,13 +1068,18 @@ get_soil_txt <- function(file = "param.sol",
   vec <- apply(vec, MARGIN = 1, FUN = list)
 
   soil[c(
-    "numsol", "epc", "hccf", "hminf", "DAF",
-    "cailloux", "typecailloux", "infil", "epd"
+    "numsol",
+    "epc",
+    "hccf",
+    "hminf",
+    "DAF",
+    "cailloux",
+    "typecailloux",
+    "infil",
+    "epd"
   )] <-
     lapply(vec, unlist)
 
-
-
   # Transform into numeric:
   soil <- character_to_numeric_list(soil)
 
@@ -987,12 +1091,15 @@ get_soil_txt <- function(file = "param.sol",
 
 #' @rdname get_param_txt
 #' @export
-get_station_txt <- function(file = "station.txt",
-                            filepath = lifecycle::deprecated()) {
+get_station_txt <- function(
+  file = "station.txt",
+  filepath = lifecycle::deprecated()
+) {
   # filepath
   if (lifecycle::is_present(filepath)) {
     lifecycle::deprecate_warn(
-      "1.0.0", "get_station_txt(filepath)",
+      "1.0.0",
+      "get_station_txt(filepath)",
       "get_station_txt(file)"
     )
   } else {
@@ -1005,14 +1112,16 @@ get_station_txt <- function(file = "station.txt",
 
 #' @rdname get_param_txt
 #' @export
-get_usm_txt <- function(file = "new_travail.usm",
-                        plant_id = NULL,
-                        filepath = lifecycle::deprecated()) {
-
+get_usm_txt <- function(
+  file = "new_travail.usm",
+  plant_id = NULL,
+  filepath = lifecycle::deprecated()
+) {
   # filepath
   if (lifecycle::is_present(filepath)) {
     lifecycle::deprecate_warn(
-      "1.0.0", "get_usm_txt(filepath)",
+      "1.0.0",
+      "get_usm_txt(filepath)",
       "get_usm_txt(file)"
     )
   } else {
@@ -1023,8 +1132,12 @@ get_usm_txt <- function(file = "new_travail.usm",
 
   idx <- plant_id == 1:2
 
-  if (is.null(plant_id) ||
-      (length(plant_id) == 2 && all(idx))) return(usm_params)
+  if (
+    is.null(plant_id) ||
+      (length(plant_id) == 2 && all(idx))
+  ) {
+    return(usm_params)
+  }
 
   # getting specific info attached to plant id
   # fplt1 ou fplt2, ftec1 ou ftec2, flai1 ou flai2,
@@ -1057,16 +1170,17 @@ get_usm_txt <- function(file = "new_travail.usm",
 #'
 #' @examples
 #' \dontrun{
-#' path <- file.path(get_examples_path(file_type = "txt",
-#'                                    stics_version = "V8.5"), "station.txt")
+#' path <- file.path(get_examples_path(
+#'   file_type = "txt",
+#'   stics_version = "V8.5"
+#' ), "station.txt")
 #' get_txt_generic(path)
 #' }
 #'
-get_txt_generic <- function(file,
-                            names = TRUE) {
-
-  if (!file.exists(file))
+get_txt_generic <- function(file, names = TRUE) {
+  if (!file.exists(file)) {
     stop(file, ": does not exist !")
+  }
 
   params <- readLines(file)
 
@@ -1089,7 +1203,6 @@ get_txt_generic <- function(file,
 }
 
 
-
 #' Character list to numeric list
 #'
 #' @description Tries to convert the values in a list into numeric values,
@@ -1125,12 +1238,13 @@ char2num <- function(x) {
     return(x)
   }
 
-  if (!all(grepl(pattern = "[0-9]", x = x)) ||
-      any(grepl(pattern = "[a-zA-Z]", x = x))) {
+  if (
+    !all(grepl(pattern = "[0-9]", x = x)) ||
+      any(grepl(pattern = "[a-zA-Z]", x = x))
+  ) {
     return(x)
   }
 
-
   as.numeric(unlist(strsplit(x_trim, split = " ")))
 }
 
