@@ -11,10 +11,10 @@
 #'
 #' @noRd
 #'
-get_params_from_doc_node <- function(xml_node,
-                                     param_list = c(),
-                                     unique_val = TRUE) {
-
+get_params_from_doc_node <- function(
+    xml_node,
+    param_list = c(),
+    unique_val = TRUE) {
   # for ini, usms files
 
   if (!methods::is(xml_node, "XMLInternalElementNode")) {
