@@ -20,24 +20,24 @@
 #' # Getting the previous version of the latest one
 #' get_stics_versions_compat(-1)
 #'
-#'
 #' @export
 #'
 #'
 get_stics_versions_compat <- function(version_index = NULL) {
-
   # Getting versions list
   ver_info <- get_versions_info()
   versions_names <- ver_info$versions
-  #num_versions <- as.numeric(gsub(pattern = "^[V]", "", versions_names))
+  # num_versions <- as.numeric(gsub(pattern = "^[V]", "", versions_names))
   num_versions <- get_version_num(versions_names)
 
   # Getting the latest version string
   latest_version <- versions_names[num_versions == max(num_versions)]
 
   # List of versions strings ans latest version string
-  versions <- list(versions_list = versions_names,
-                   latest_version = latest_version)
+  versions <- list(
+    versions_list = versions_names,
+    latest_version = latest_version
+  )
 
   if (is.null(version_index)) {
     return(versions)
@@ -46,7 +46,6 @@ get_stics_versions_compat <- function(version_index = NULL) {
   # getting relative backwards versions
   nb_versions <- length(versions$versions_list)
 
-
   if (version_index < 0) {
     if (version_index >= -nb_versions + 1) {
       return(versions$versions_list[nb_versions + version_index])
@@ -88,7 +87,6 @@ check_version_compat <- function(stics_version = "latest") {
     return(versions$latest_version)
   }
 
-
   if (stics_version %in% versions$versions_list) {
     return(stics_version)
   }
@@ -102,7 +100,7 @@ check_version_compat <- function(stics_version = "latest") {
 #' @param stics_version Optional version string (i.e. "VX.Y")
 #'
 #' @param versions_dir Optional, either an `extdata` directory path
-#' of the installed SticsRFiles library (default) or of the package project
+#' of the installed `SticsRFiles` library (default) or of the package project
 #'
 #' @return A data.frame with versions data
 #'
@@ -124,7 +122,6 @@ check_version_compat <- function(stics_version = "latest") {
 #' )
 #' }
 get_versions_info <- function(stics_version = NULL, location = "install") {
-
   # Getting available versions info from a file
   ver_file <- get_versions_file_path(location = location)
 
@@ -133,7 +130,8 @@ get_versions_info <- function(stics_version = NULL, location = "install") {
   }
 
   ver_info <- utils::read.csv2(
-    file = ver_file, stringsAsFactors = FALSE,
+    file = ver_file,
+    stringsAsFactors = FALSE,
     colClasses = "character"
   )
 
@@ -170,10 +168,10 @@ get_versions_info <- function(stics_version = NULL, location = "install") {
 #' get_version_num()
 #' }
 get_version_num <- function(stics_version = "latest", numeric = TRUE) {
-  if(length(stics_version) > 1) {
-    versions_list <- unlist(lapply(stics_version, function(x){
-      get_version_num(x, numeric = numeric)}
-    ))
+  if (length(stics_version) > 1) {
+    versions_list <- unlist(lapply(stics_version, function(x) {
+      get_version_num(x, numeric = numeric)
+    }))
     return(versions_list)
   }
 
@@ -185,17 +183,21 @@ get_version_num <- function(stics_version = "latest", numeric = TRUE) {
     stics_version <- get_stics_versions_compat()$latest_version
   }
 
-  char_version <- gsub(pattern = "([V | v]{1})([0-9\\.]*)",
-                       x = stics_version,
-                       replacement = "\\2")
+  char_version <- gsub(
+    pattern = "([V | v]{1})([0-9\\.]*)",
+    x = stics_version,
+    replacement = "\\2"
+  )
 
   if (!numeric) {
     return(char_version)
   }
 
-  char_version <- gsub(pattern = "([0-9]*\\.[0-9]*)([\\.]{0,1})([0-9]{0,})",
-                       x = char_version,
-                       replacement = "\\1\\3")
+  char_version <- gsub(
+    pattern = "([0-9]*\\.[0-9]*)([\\.]{0,1})([0-9]{0,})",
+    x = char_version,
+    replacement = "\\1\\3"
+  )
   as.numeric(char_version)
 }
 
@@ -215,8 +217,10 @@ get_version_num <- function(stics_version = "latest", numeric = TRUE) {
 get_version_string <- function(stics_version) {
   pattern <- "^[V | v]"
 
-  if (is.character(stics_version) &&
-      grepl(pattern = pattern, x = stics_version)) {
+  if (
+    is.character(stics_version) &&
+      grepl(pattern = pattern, x = stics_version)
+  ) {
     return(toupper(stics_version))
   }
 
@@ -238,4 +242,3 @@ get_version_string <- function(stics_version) {
 get_versions_file_name <- function() {
   return("stics_versions_info.csv")
 }
-
