@@ -24,13 +24,13 @@
 #' @noRd
 #'
 # TODO: under construction !!!!!!!!!!!!!!!!!
-get_xml_base_node <- function(file_tag, form_name = NULL,
-                              stics_version = "latest") {
-
+get_xml_base_node <- function(
+    file_tag,
+    form_name = NULL,
+    stics_version = "latest") {
   # check/get STICS version
   stics_version <- get_xml_stics_version(stics_version = stics_version)
 
-
   files_tags <- c("usms", "sols", "tec")
   node_names <- c("usm", "sol", "intervention")
   parent_nodes <- c("usms", "sols", "ta")
@@ -54,7 +54,6 @@ get_xml_base_node <- function(file_tag, form_name = NULL,
   formalism_names$usms <- c()
   formalism_names$sols <- c()
 
-
   if (!nargs()) {
     return(list(
       files_tags = files_tags,
@@ -65,8 +64,6 @@ get_xml_base_node <- function(file_tag, form_name = NULL,
     ))
   }
 
-
-
   # see if needed: plt -> cultivars ?
 
   file_idx <- files_tags %in% file_tag
@@ -99,7 +96,8 @@ get_xml_base_node <- function(file_tag, form_name = NULL,
   # Template path in the library
   xml_file <- file.path(
     get_examples_path(file_type = "xml_tmpl", stics_version = stics_version),
-    file_name)
+    file_name
+  )
 
   # Loading the template into an xmDocument
   xml_doc <- xmldocument(xml_file)
@@ -111,7 +109,8 @@ get_xml_base_node <- function(file_tag, form_name = NULL,
   # Getting the node from a node set
   new_node <- XML::getNodeSet(
     XML::xmlParse(base_node_txt),
-    paste0("//", node))[[1]]
+    paste0("//", node)
+  )[[1]]
 
   delete(xml_doc)
 
