@@ -19,16 +19,17 @@
 #'
 #' @noRd
 #'
-get_xml_doc_example <- function(xml_name = NULL,
-                                stics_version = "latest") {
-
+get_xml_doc_example <- function(xml_name = NULL, stics_version = "latest") {
   # check/get version
   stics_version <- get_xml_stics_version(stics_version = stics_version)
 
   # stics_xml_types
-  files <- list.files(pattern = ".xml$",
-                      path = get_examples_path(file_type = "xml",
-                                               stics_version = stics_version)
+  files <- list.files(
+    pattern = ".xml$",
+    path = get_examples_path(
+      file_type = "xml",
+      stics_version = stics_version
+    )
   )
 
   if (base::is.null(xml_name)) {
@@ -36,14 +37,19 @@ get_xml_doc_example <- function(xml_name = NULL,
   }
 
   if (!xml_name %in% files) {
-    stop("File does not exist in package examples,",
-         "run get_xml_example_doc() to get the list !")
+    stop(
+      "File does not exist in package examples,",
+      "run get_xml_example_doc() to get the list !"
+    )
   }
 
   # getting a default xmldocument object template
-  xml_file <- file.path(get_examples_path(file_type = "xml",
-                                          stics_version = stics_version),
-                        xml_name
+  xml_file <- file.path(
+    get_examples_path(
+      file_type = "xml",
+      stics_version = stics_version
+    ),
+    xml_name
   )
   xml_doc_object <- xmldocument(xml_file)
 
