@@ -26,14 +26,18 @@
 #'   stics_version = "V9.2"
 #' )
 #' read_params_table(file = usm_csv_file)
-read_params_table <- function(file, sheet_name = NULL,
-                              num_na = "NA",
-                              char_na = "NA",
-                              file_path = lifecycle::deprecated()) {
+read_params_table <- function(
+    file,
+    sheet_name = NULL,
+    num_na = "NA",
+    char_na = "NA",
+    file_path = lifecycle::deprecated()) {
   if (lifecycle::is_present(file_path)) {
-    lifecycle::deprecate_warn("1.0.0",
-                              "read_params_table(file_path)",
-                              "read_params_table(file)")
+    lifecycle::deprecate_warn(
+      "1.0.0",
+      "read_params_table(file_path)",
+      "read_params_table(file)"
+    )
   } else {
     file_path <- file # to remove when we update inside the function
   }
@@ -57,7 +61,6 @@ read_params_table <- function(file, sheet_name = NULL,
   # If the sheet name is not provided
   if (!length(sheet_exists)) sheet_exists <- FALSE
 
-
   # Unknown sheet in XL file
   if (isFALSE(sheet_exists)) {
     warning(paste(
@@ -83,10 +86,12 @@ read_params_table <- function(file, sheet_name = NULL,
       )
     },
     {
-      out_table <- readxl::read_excel(file_path,
-                                      sheet = sheet_name,
-                                      trim_ws = TRUE,
-                                      col_types = "text")
+      out_table <- readxl::read_excel(
+        file_path,
+        sheet = sheet_name,
+        trim_ws = TRUE,
+        col_types = "text"
+      )
     }
   )
 
@@ -132,16 +137,16 @@ replace_na <- function(in_df, replacement) {
     }
   )
 
-
   # Nothing to be replaced
   if (isFALSE(any(idx_type_col))) {
     return(in_df)
   }
 
-  idx_col_has_na <- unlist(lapply(in_df, function(x) {
-    any(is.na(x))
-  }),
-  use.names = FALSE
+  idx_col_has_na <- unlist(
+    lapply(in_df, function(x) {
+      any(is.na(x))
+    }),
+    use.names = FALSE
   )
 
   to_be_treated <- which(idx_type_col & idx_col_has_na)
@@ -155,6 +160,5 @@ replace_na <- function(in_df, replacement) {
     in_df[is.na(in_df[, i]), i] <- replacement
   }
 
-
   in_df
 }
