@@ -13,10 +13,11 @@
 #'
 #' @noRd
 #'
-replace_string_in_file <- function(file_path,
-                                   target_string,
-                                   replace_string,
-                                   new_file_path = NULL) {
+replace_string_in_file <- function(
+    file_path,
+    target_string,
+    replace_string,
+    new_file_path = NULL) {
   if (!file.exists(file_path)) {
     warning(paste(file_path, "doesn't exist, aborting !"))
     return()
@@ -27,15 +28,17 @@ replace_string_in_file <- function(file_path,
     in_place <- ""
     redirect <- paste(" >", new_file_path)
   }
-  cmd <- paste0("perl -p",
-                in_place,
-                " -e 's/",
-                target_string,
-                "/",
-                replace_string,
-                "/g ' ",
-                file_path,
-                redirect)
+  cmd <- paste0(
+    "perl -p",
+    in_place,
+    " -e 's/",
+    target_string,
+    "/",
+    replace_string,
+    "/g ' ",
+    file_path,
+    redirect
+  )
 
   system(cmd)
 }
