@@ -31,30 +31,29 @@
 #' )
 #'
 #'
-upgrade_param_newform_xml <- function(file,
-                                      out_dir,
-                                      param_gen_file,
-                                      stics_version = "V9.2",
-                                      target_version = "V10.0",
-                                      check_version = TRUE,
-                                      overwrite = FALSE
-) {
-
+upgrade_param_newform_xml <- function(
+    file,
+    out_dir,
+    param_gen_file,
+    stics_version = "V9.2",
+    target_version = "V10.0",
+    check_version = TRUE,
+    overwrite = FALSE) {
   # TODO: eliminate when option will be reactivated later.
   codemineral <- FALSE
 
   # Checking output directory
   if (!dir.exists(out_dir)) dir.create(out_dir)
 
-
   if (check_version) {
     min_version <- get_version_num("V9.1")
 
     # Extracting or detecting the STICS version corresponding to the xml file
     # based on param_gen.xml file content
-    file_version <- check_xml_file_version(file,
-                                           stics_version,
-                                           param_gen_file = param_gen_file
+    file_version <- check_xml_file_version(
+      file,
+      stics_version,
+      param_gen_file = param_gen_file
     )
 
     if (!file_version && is.null(param_gen_file)) {
@@ -63,9 +62,12 @@ upgrade_param_newform_xml <- function(file,
 
     if (!file_version) {
       stop(
-        "The input version ", stics_version,
+        "The input version ",
+        stics_version,
         " does not match file version ",
-        attr(file_version, "version"), " \n", file
+        attr(file_version, "version"),
+        " \n",
+        file
       )
     }
 
@@ -73,27 +75,26 @@ upgrade_param_newform_xml <- function(file,
     ver_num <- get_version_num(stics_version)
     if (ver_num < min_version) {
       stop(
-        "Files from the version ", stics_version,
-        " cannot be converted to the version ", target_version
+        "Files from the version ",
+        stics_version,
+        " cannot be converted to the version ",
+        target_version
       )
     }
   }
 
-
-
   # Loading the old doc
   old_doc <- xmldocument(file = file)
 
   # Setting file STICS version
-  set_xml_file_version(old_doc,
-                       new_version = target_version,
-                       overwrite = overwrite)
-
+  set_xml_file_version(
+    old_doc,
+    new_version = target_version,
+    overwrite = overwrite
+  )
 
   # TODO : add from here if cond for calling specific version ranges updates
 
-
-
   # nodes to remove
   form_names <- c(
     "Specificities of cut crops",
@@ -101,8 +102,10 @@ upgrade_param_newform_xml <- function(file,
     "Calculation of the maximal reserve compartment during reproductive stages",
     "Calculation of the stem elongation stage for perenial grasslands",
     "Moisture test for sowing decision",
-    paste0("automatic irrigations (associated with the options of automatic ",
-           "irrigation in tec file)"),
+    paste0(
+      "automatic irrigations (associated with the options of automatic ",
+      "irrigation in tec file)"
+    ),
     "calculation of the root death at cutting date for grasslands",
     "option for several thinning ",
     "option for several fertilizer type ",
@@ -119,7 +122,6 @@ upgrade_param_newform_xml <- function(file,
 
   lapply(nodes_to_rm, function(x) if (!is.null(x)) XML::removeNodes(x))
 
-
   # options to be removed
   opt_names <- c(
     "New mineralization of soil organic matter "
@@ -153,14 +155,15 @@ upgrade_param_newform_xml <- function(file,
   parent_node <- prev_sibling
 
   if (codemineral) {
-
-    new_node <- list(XML::xmlParseString(
-      '<option choix="1" nom="New mineralization model" nomParam="codemineral">
+    new_node <- list(
+      XML::xmlParseString(
+        '<option choix="1" nom="New mineralization model" nomParam="codemineral">
   <choix code="1" nom="no"/>
   <choix code="2" nom="new_minr"/>
   <choix code="3" nom="new_minh+new_minr"/>
 </option>',
-      addFinalizer = TRUE),
+        addFinalizer = TRUE
+      ),
       XML::xmlParseString(
         '<option choix="2" nom="CsurNsol dynamic"
       nomParam="code_CsurNsol_dynamic">
@@ -168,13 +171,14 @@ upgrade_param_newform_xml <- function(file,
   <choix code="2" nom="no"/>
 </option>',
         addFinalizer = TRUE
-      ))
+      )
+    )
 
-    lapply(new_node,
-           function(x) XML::addChildren(parent_node, XML::xmlClone(x))
+    lapply(
+      new_node,
+      function(x) XML::addChildren(parent_node, XML::xmlClone(x))
     )
   } else {
-
     # if a version 10.0 file is retreated
     # codemineral option must be retreived for the moment
 
@@ -197,7 +201,6 @@ upgrade_param_newform_xml <- function(file,
     XML::addChildren(parent_node, XML::xmlClone(new_node))
   }
 
-
   # formalism modifications
   # replacing formalisme option @nom, choix
   set_attrs_values(
@@ -211,8 +214,10 @@ upgrade_param_newform_xml <- function(file,
     old_doc,
     path = "//option[@nomParam='codetesthumN']",
     attr_name = "nom",
-    values_list = paste0("automatic N fertilisation (1 = based on rainfall",
-                         " 2 = based on soil water content)")
+    values_list = paste0(
+      "automatic N fertilisation (1 = based on rainfall",
+      " 2 = based on soil water content)"
+    )
   )
 
   set_attrs_values(
@@ -222,12 +227,11 @@ upgrade_param_newform_xml <- function(file,
     values_list = "1"
   )
 
-
-
   # TODO: see what to do for the future v10 version !
   # ---------------------------------------------------------------------------
   # ISOP specific option to temporarily add
-  new_node <- XML::xmlParseString('<formalisme nom="ISOP">
+  new_node <- XML::xmlParseString(
+    '<formalisme nom="ISOP">
 		<option choix="2" nom="activation of ISOP equations" nomParam="code_ISOP">
 			<choix code="1" nom="yes">
 			<option choix="2" nom="activation of legume fixation in grassland"
@@ -241,7 +245,7 @@ upgrade_param_newform_xml <- function(file,
 			<choix code="2" nom="no"/>
 		</option>
    </formalisme>',
-                                  addFinalizer = TRUE
+    addFinalizer = TRUE
   )
 
   prev_sibling <- get_nodes(
@@ -251,11 +255,12 @@ upgrade_param_newform_xml <- function(file,
   XML::addSibling(prev_sibling, XML::xmlClone(new_node))
   # ---------------------------------------------------------------------------
 
-
   # Writing to file param_newform.xml
-  write_xml_file(old_doc,
-                 file.path(out_dir, basename(file)),
-                 overwrite = overwrite)
+  write_xml_file(
+    old_doc,
+    file.path(out_dir, basename(file)),
+    overwrite = overwrite
+  )
 
   XML::free(old_doc@content)
   invisible(gc(verbose = FALSE))
