@@ -27,24 +27,22 @@
 #' dir_path <- get_examples_path(file_type = "xml", stics_version = "V9.2")
 #'
 #' upgrade_plt_xml(
-#'   file = file.path(dir_path,"file_plt.xml"),
+#'   file = file.path(dir_path, "file_plt.xml"),
 #'   out_dir = tempdir(),
 #'   param_newform_file = file.path(dir_path, "param_newform.xml"),
 #'   param_gen_file = file.path(dir_path, "param_gen.xml")
 #' )
 #'
-upgrade_plt_xml <- function(file,
-                            out_dir,
-                            param_newform_file,
-                            param_gen_file,
-                            stics_version = "V9.2",
-                            target_version = "V10.0",
-                            check_version = TRUE,
-                            overwrite = FALSE,
-                            ...) {
-
-
-
+upgrade_plt_xml <- function(
+    file,
+    out_dir,
+    param_newform_file,
+    param_gen_file,
+    stics_version = "V9.2",
+    target_version = "V10.0",
+    check_version = TRUE,
+    overwrite = FALSE,
+    ...) {
   # For verifying output dir existence
   check_dir <- TRUE
   args_list <- list(...)
@@ -61,21 +59,24 @@ upgrade_plt_xml <- function(file,
 
     # extracting or detecting the STICS version corresponding to the xml file
     # based on param_gen.xml file content
-    file_version <- check_xml_file_version(file[1],
-                                           stics_version,
-                                           param_gen_file = param_gen_file
+    file_version <- check_xml_file_version(
+      file[1],
+      stics_version,
+      param_gen_file = param_gen_file
     )
 
-
     if (!file_version && is.null(param_gen_file)) {
       stop("param_gen_file must be provided! ")
     }
 
     if (!file_version) {
       stop(
-        "The input version ", stics_version,
+        "The input version ",
+        stics_version,
         " does not match file version ",
-        attr(file_version, "version"), " \n", file[1]
+        attr(file_version, "version"),
+        " \n",
+        file[1]
       )
     }
 
@@ -83,17 +84,17 @@ upgrade_plt_xml <- function(file,
     ver_num <- get_version_num(stics_version)
     if (ver_num < min_version) {
       stop(
-        "Files from the version ", stics_version,
-        " cannot be converted to the version ", target_version
+        "Files from the version ",
+        stics_version,
+        " cannot be converted to the version ",
+        target_version
       )
     }
 
-
     # for checking only once when multiple files are treated !
     check_version <- FALSE
   }
 
-
   # Treating a files list
   if (length(file) > 1) {
     lapply(file, function(x) {
@@ -118,24 +119,50 @@ upgrade_plt_xml <- function(file,
   # Loading the old xml file
   old_doc <- xmldocument(file = file)
 
-
   # Setting file STICS version
-  set_xml_file_version(old_doc, new_version = target_version,
-                       overwrite = overwrite)
-
+  set_xml_file_version(
+    old_doc,
+    new_version = target_version,
+    overwrite = overwrite
+  )
 
   # Parameters to move to varietal parameters ----------------------------------
   #
   # Coming from other formalisms than varietal ones
   # Storing parameters values to set them to varietal ones
   param_names_to_varietal <- c(
-    "phobase", "phosat", "stdordebour", "bdens", "hautbase", "hautmax",
-    "dlaimax", "dlaimaxbrut", "innsen", "rapsenturg", "extin", "ktrou", "temin",
-    "teopt", "slamax", "tigefeuil", "nbjgrain", "nbgrmin", "vitircarb",
-    "vitircarbT", "stdrpnou", "nbinflo", "inflomax", "pentinflores",
-    "vitpropsucre", "vitprophuile", "vitirazo",
-    "tgellev10", "tgeljuv10", "tgelveg10",
-    "psisto", "psiturg",
+    "phobase",
+    "phosat",
+    "stdordebour",
+    "bdens",
+    "hautbase",
+    "hautmax",
+    "dlaimax",
+    "dlaimaxbrut",
+    "innsen",
+    "rapsenturg",
+    "extin",
+    "ktrou",
+    "temin",
+    "teopt",
+    "slamax",
+    "tigefeuil",
+    "nbjgrain",
+    "nbgrmin",
+    "vitircarb",
+    "vitircarbT",
+    "stdrpnou",
+    "nbinflo",
+    "inflomax",
+    "pentinflores",
+    "vitpropsucre",
+    "vitprophuile",
+    "vitirazo",
+    "tgellev10",
+    "tgeljuv10",
+    "tgelveg10",
+    "psisto",
+    "psiturg",
     "deshydbase"
   )
   param_values_to_varietal <- get_param_value(old_doc, param_names_to_varietal)
@@ -144,8 +171,11 @@ upgrade_plt_xml <- function(file,
   nodes_to_rm <- lapply(param_names_to_varietal, function(x) {
     get_nodes(
       old_doc,
-      path = paste0("//formalisme[@nom!='cultivar parameters']//param[@nom='",
-                    x, "']")
+      path = paste0(
+        "//formalisme[@nom!='cultivar parameters']//param[@nom='",
+        x,
+        "']"
+      )
     )
   })
 
@@ -156,13 +186,26 @@ upgrade_plt_xml <- function(file,
   # Removing nodes
   lapply(nodes_to_rm, function(x) XML::removeNodes(x))
 
-
   # Already exist in varietal parameters
   # Storing parameters values before applying new varietal parameters structure
   param_names_keep <- c(
-    "stlevamf", "stamflax", "stlevdrp", "stflodrp", "stdrpdes", "pgrainmaxi",
-    "adens", "croirac", "durvieF", "jvc", "sensiphot", "stlaxsen", "stsenlan",
-    "nbgrmax", "stdrpmat", "afruitpot", "dureefruit"
+    "stlevamf",
+    "stamflax",
+    "stlevdrp",
+    "stflodrp",
+    "stdrpdes",
+    "pgrainmaxi",
+    "adens",
+    "croirac",
+    "durvieF",
+    "jvc",
+    "sensiphot",
+    "stlaxsen",
+    "stsenlan",
+    "nbgrmax",
+    "stdrpmat",
+    "afruitpot",
+    "dureefruit"
   )
 
   param_values_keep <- get_param_value(old_doc, param_names_keep)
@@ -172,7 +215,6 @@ upgrade_plt_xml <- function(file,
     stop("Missing values, , not a v9.1 or 9.2 _plt.xml file")
   }
 
-
   # General plant parameters ---------------------------------------------------
   #
   # adding codephot_part
@@ -186,64 +228,74 @@ upgrade_plt_xml <- function(file,
   )
 
   # test if the node exists
-  node_exists <- !is.null(get_nodes(old_doc,
-                                    '//option[@nomParam="codephot_part"]'))
+  node_exists <- !is.null(get_nodes(
+    old_doc,
+    '//option[@nomParam="codephot_part"]'
+  ))
 
-  if (node_exists) stop(
-    "codephot_part already exists, not a v9.1 or 9.2 _plt.xml file")
+  if (node_exists) {
+    stop(
+      "codephot_part already exists, not a v9.1 or 9.2 _plt.xml file"
+    )
+  }
 
   parent_node <- get_nodes(
     old_doc,
-    '//option[@nomParam="codephot"]/choix[@code="1"]')[[1]]
+    '//option[@nomParam="codephot"]/choix[@code="1"]'
+  )[[1]]
 
   XML::addChildren(parent_node, XML::xmlClone(new_node))
 
-
   # moving nbfeuilplant
   node_to_move <- get_nodes(old_doc, path = "//param[@nom='nbfeuilplant']")[[1]]
   prev_sibling <- get_nodes(old_doc, path = "//param[@nom='laiplantule']")[[1]]
 
   XML::addSibling(prev_sibling, node_to_move)
 
-
-
   # Recalculating irazomax
   irazomax_calc <- calc_irazomax(
     get_param_value(old_doc, "irmax")$irmax,
     param_values_to_varietal$vitircarb,
-    param_values_to_varietal$vitirazo)
+    param_values_to_varietal$vitirazo
+  )
 
   new_node <- XML::xmlParseString(
-    paste0('<param format="real" max="1.0" min="0.01" nom="irazomax">',
-           irazomax_calc,
-           "</param>"),
+    paste0(
+      '<param format="real" max="1.0" min="0.01" nom="irazomax">',
+      irazomax_calc,
+      "</param>"
+    ),
     addFinalizer = TRUE
   )
 
   # adding irazomax node
-  parent_node <- get_nodes(old_doc,
-                           path = "//formalisme[@nom='yield formation']")[[1]]
+  parent_node <- get_nodes(
+    old_doc,
+    path = "//formalisme[@nom='yield formation']"
+  )[[1]]
   XML::addChildren(parent_node, new_node, at = 0)
 
-
-  message(old_doc@name,
-          ": be aware that irazomax is a new parameter and its value (",
-          irazomax_calc,
-          ")\nis estimated using some other parameters values.\n",
-          paste0("But this value needs to be ajusted according to ",
-                 "species and varieties "), "\n")
-
+  message(
+    old_doc@name,
+    ": be aware that irazomax is a new parameter and its value (",
+    irazomax_calc,
+    ")\nis estimated using some other parameters values.\n",
+    paste0(
+      "But this value needs to be ajusted according to ",
+      "species and varieties "
+    ),
+    "\n"
+  )
 
   # moving irmax
   node_to_move <- get_nodes(old_doc, path = "//param[@nom='irmax']")[[1]]
   parent_node <- get_nodes(
     old_doc,
-    path = "//option[@nomParam='codeir']/choix[@code='1']")[[1]]
+    path = "//option[@nomParam='codeir']/choix[@code='1']"
+  )[[1]]
 
   XML::addChildren(parent_node, node_to_move)
 
-
-
   # add codedisrac option node
   new_node <- XML::xmlParseString(
     '<option choix="2" nom="Standard root distribution" nomParam="codedisrac">
@@ -260,7 +312,6 @@ upgrade_plt_xml <- function(file,
   prev_sibling <- get_nodes(old_doc, '//option[@nomParam="codazorac"]')[[1]]
   XML::addSibling(prev_sibling, new_node, after = FALSE)
 
-
   # Changing varietal section structure ----------------------------------------
   #
   # Remove nodes from old doc for varietal content (under variete nodes)
@@ -394,14 +445,13 @@ upgrade_plt_xml <- function(file,
     addFinalizer = TRUE
   )
 
-
   # adding var nodes under each "variete" node
   var_parent_nodes <- get_nodes(old_doc, path = "//variete")
-  lapply(var_parent_nodes,
-         function(x) {
-           XML::addChildren(x,
-                            kids = XML::xmlChildren(XML::xmlClone(var_nodes)))
-         }
+  lapply(
+    var_parent_nodes,
+    function(x) {
+      XML::addChildren(x, kids = XML::xmlChildren(XML::xmlClone(var_nodes)))
+    }
   )
 
   #
@@ -411,7 +461,6 @@ upgrade_plt_xml <- function(file,
   set_param_value(old_doc, param_names_to_varietal, param_values_to_varietal)
   set_param_value(old_doc, param_names_keep, param_values_keep)
 
-
   # Special case: jvc not any more under an option choice
   # Checking values for jvc, if == -999, and replacing with
   # a value set in new files provided with JavaSTICS
@@ -427,32 +476,38 @@ upgrade_plt_xml <- function(file,
 
   load(
     file.path(
-      get_examples_path(file_type = "xml_param",
-                        stics_version = target_version
+      get_examples_path(
+        file_type = "xml_param",
+        stics_version = target_version
       ),
-      "jvc_data.RData")
+      "jvc_data.RData"
+    )
   )
 
   # get varieties
   current_var <- get_param_value(old_doc, "variete")
 
   if (basename(file) %in% names(jvc_data)) {
-
     common_var <-
       jvc_data[[basename(file)]][["variete"]] %in% current_var$variete
 
     if (any(common_var)) {
-      values <- get_param_value(old_doc, param_name = "jvc",
-                                parent_name = "variete",
-                                parent_sel_attr = current_var[common_var])$jvc
+      values <- get_param_value(
+        old_doc,
+        param_name = "jvc",
+        parent_name = "variete",
+        parent_sel_attr = current_var[common_var]
+      )$jvc
 
       values_999_ids <- which(values == -999)
       if (length(values_999_ids) > 0) {
         jvc_values <- jvc_data[[basename(file)]]$jvc[common_var][values_999_ids]
-        set_param_value(old_doc,
-                        param_name = "jvc",
-                        param_value = jvc_values,
-                        ids = values_999_ids)
+        set_param_value(
+          old_doc,
+          param_name = "jvc",
+          param_value = jvc_values,
+          ids = values_999_ids
+        )
       }
     }
   }
@@ -461,13 +516,18 @@ upgrade_plt_xml <- function(file,
   # Check if still any -999 values
   values <- get_param_value(old_doc, "jvc")$jvc
   values_999_ids <- which(values == -999)
-  if (length(values_999_ids) > 0)
-    message(old_doc@name,
-            paste0(": be aware that jvc is from now a mandatory parameter",
-                   "and its value must be fixed !\n"),
-            "for all varieties: \n", current_var[values_999_ids], "\n")
-
-
+  if (length(values_999_ids) > 0) {
+    message(
+      old_doc@name,
+      paste0(
+        ": be aware that jvc is from now a mandatory parameter",
+        "and its value must be fixed !\n"
+      ),
+      "for all varieties: \n",
+      current_var[values_999_ids],
+      "\n"
+    )
+  }
 
   # Adding new nodes
   #
@@ -488,7 +548,6 @@ upgrade_plt_xml <- function(file,
   prev_sibling <- get_nodes(old_doc, "//*[@nomParam='codetemprac']")[[1]]
   XML::addSibling(prev_sibling, XML::xmlClone(new_node))
 
-
   # code_WangEngel
   # in <choix code="1" nom="daily temperatures">
   new_node <- XML::xmlParseString(
@@ -501,11 +560,12 @@ upgrade_plt_xml <- function(file,
     addFinalizer = TRUE
   )
 
-  parent_node <- get_nodes(old_doc,
-                           "//*[@nomParam='codegdhdeb']/choix[@code='1']")[[1]]
+  parent_node <- get_nodes(
+    old_doc,
+    "//*[@nomParam='codegdhdeb']/choix[@code='1']"
+  )[[1]]
   XML::addChildren(parent_node, new_node)
 
-
   # Adding 2 option nodes
   # in <formalisme nom="partitioning of biomass in organs">
   #
@@ -567,7 +627,6 @@ nomParam="codedyntalle">
   )[[1]]
   XML::addChildren(parent_node, kids = unlist(XML::xmlChildren(new_nodes)))
 
-
   # <formalisme nom="roots">
   # rayon
   #
@@ -608,7 +667,6 @@ nomParam="codedyntalle">
 
   XML::addChildren(parent_node, kids = unlist(XML::xmlChildren(new_nodes)))
 
-
   # -----------------------------------------------------------
   # Update param values
   #
@@ -618,10 +676,11 @@ nomParam="codedyntalle">
     file = param_gen_file,
     param = c("rayon", "khaut")
   )[[1]]
-  set_param_value(old_doc,
-                  param_name = c("rayon", "khaut"),
-                  param_value = param_gen_values)
-
+  set_param_value(
+    old_doc,
+    param_name = c("rayon", "khaut"),
+    param_value = param_gen_values
+  )
 
   # from param_newform.xml
   # coefracoupe(1), coefracoupe(2) -> coefracoupe
@@ -630,13 +689,17 @@ nomParam="codedyntalle">
     param = c("coefracoupe(1)", "coefracoupe(2)")
   )[[1]]
 
-  if (length(unique(unlist(param_newform_values))) > 1)
+  if (length(unique(unlist(param_newform_values))) > 1) {
     stop(
-      "Multiple values of coefracoupe in param_gen.xml file")
-
-  set_param_value(old_doc, param_name = "coefracoupe",
-                  param_value = param_newform_values[[1]])
+      "Multiple values of coefracoupe in param_gen.xml file"
+    )
+  }
 
+  set_param_value(
+    old_doc,
+    param_name = "coefracoupe",
+    param_value = param_newform_values[[1]]
+  )
 
   # Updating other values than nodes values (i.e. nodes attributes values)
   #
@@ -645,8 +708,12 @@ nomParam="codedyntalle">
   # <param format="real" max="2.0" min="0.0" nom="hautbase">0</param>
   nodes_to_change <- get_nodes(old_doc, path = "//param[@nom='hautbase']")
   if (!is.null(nodes_to_change)) {
-    set_attrs_values(old_doc, path = "//param[@nom='hautbase']",
-                     attr_name = "min", values_list = "0.1")
+    set_attrs_values(
+      old_doc,
+      path = "//param[@nom='hautbase']",
+      attr_name = "min",
+      values_list = "0.1"
+    )
   }
   #
   # Changing options' "choix",  "nom" attribute values
@@ -654,33 +721,33 @@ nomParam="codedyntalle">
   # oui to yes, non to no
   nodes_to_change <- get_nodes(old_doc, path = "//choix[@nom='oui']")
   if (!is.null(nodes_to_change)) {
-    set_attrs_values(old_doc, path = "//choix[@nom='oui']", attr_name = "nom",
-                     values_list = "yes")
+    set_attrs_values(
+      old_doc,
+      path = "//choix[@nom='oui']",
+      attr_name = "nom",
+      values_list = "yes"
+    )
   }
   nodes_to_change <- get_nodes(old_doc, path = "//choix[@nom='non']")
   if (!is.null(nodes_to_change)) {
-    set_attrs_values(old_doc, path = "//choix[@nom='non']", attr_name = "nom",
-                     values_list = "no")
+    set_attrs_values(
+      old_doc,
+      path = "//choix[@nom='non']",
+      attr_name = "nom",
+      values_list = "no"
+    )
   }
 
-
-
-
   # Writing to file _plt.xml
   out_plt <- file.path(out_dir, basename(file))
   write_xml_file(old_doc, out_plt, overwrite)
 
-
-
   XML::free(old_doc@content)
   invisible(gc(verbose = FALSE))
 }
 
 
-
-
 calc_irazomax <- function(irmax, vitircarb, vitirazo) {
-
   irazomax <- (irmax / vitircarb) * vitirazo
 
   irazomax <- pmin(1., irazomax)
