@@ -11,9 +11,9 @@ setClass(
 
 # object validation
 setMethod(
-  "valid_doc", signature(object = "xml_document"),
+  "valid_doc",
+  signature(object = "xml_document"),
   function(object) {
-
     ext <- get_ext(object)
 
     if (length(object@name) == 0 || object@name == "") {
@@ -29,24 +29,28 @@ setMethod(
       return(paste("Error: file is empty:", object@name, "!"))
     }
     TRUE
-  })
+  }
+)
 
 
 # constructor
 setMethod(
-  "xmldocument", signature(file = "character"),
+  "xmldocument",
+  signature(file = "character"),
   function(file = character(length = 0)) {
     suppressMessages(methods::new("xml_document", file = file))
   }
 )
 
 setMethod(
-  "initialize", "xml_document",
+  "initialize",
+  "xml_document",
   function(.Object, file = character(length = 0), warn = FALSE) {
     .Object <- methods::callNextMethod(.Object, file)
     methods::validObject(.Object)
     .Object <- load_content(.Object)
-    return(.Object)
+
+    .Object
   }
 )
 
@@ -60,31 +64,41 @@ setMethod("show", "xml_document", function(object) {
 
 # setter methods
 setReplaceMethod(
-  "set_content", signature(object = "xml_document"),
+  "set_content",
+  signature(object = "xml_document"),
   function(object, value) {
     if (!methods::is(value, "XMLInternalDocument")) {
-      stop("Input value is not a XMLInternalDocument class object")
+      warning(
+        "Input value is not a XMLInternalDocument class object",
+        "the object will not be modified"
+      )
+      return(object)
     }
     object@content <- value
-    return(object)
+
+    object
   }
 )
 
 # getter methods
 setMethod(
-  "get_content", signature(object = "xml_document"),
+  "get_content",
+  signature(object = "xml_document"),
   function(object) {
-    return(object@content)
+    object@content
   }
 )
 
 
 setMethod(
-  "get_nodes", signature(object = "xml_document"),
+  "get_nodes",
+  signature(object = "xml_document"),
   function(object, path = NULL) {
-    node_set <- NULL
     if (!is_loaded(object)) {
-      stop("xml file is not loaded in xml_document object")
+      warning("xml file is not loaded in xml_document object")
+      empty_node_set <- list()
+      attr(empty_node_set, "class") <- "XMLNodeSet"
+      return(empty_node_set)
     }
 
     if (base::is.null(path)) {
@@ -112,12 +126,14 @@ setMethod(
       if (object@warn) warning("Node set is empty, check xml input path !")
       node_set <- NULL
     }
-    return(node_set)
+
+    node_set
   }
 )
 
 setMethod(
-  "get_attrs", signature(object = "xml_document"),
+  "get_attrs",
+  signature(object = "xml_document"),
   function(object, path) {
     attr_list <- NULL
     node_set <- get_nodes(object, path)
@@ -149,14 +165,12 @@ setMethod(
       attr_list <- t(attr_list)
     }
 
-
     # testing if any node has not any attribute
     any_null <- any(sapply(attr_list, function(x) base::is.null(x)))
     if (any_null && object@warn) {
       warning(paste("Existing nodes without any attributes on xpath", path))
     }
 
-
     # testing if all nodes have the same attributes !!
     if (!is.matrix(attr_list) && !is.matrix(attr_list[, ])) {
       if (object@warn) {
@@ -169,13 +183,14 @@ setMethod(
       }
     }
 
-    return(attr_list)
+    attr_list
   }
 )
 
 # get_attrs_names
 setMethod(
-  "get_attrs_names", signature(object = "xml_document"),
+  "get_attrs_names",
+  signature(object = "xml_document"),
   function(object, path) {
     attr_names <- NULL
     attr_list <- get_attrs(object, path)
@@ -187,24 +202,22 @@ setMethod(
       attr_names <- dim_names[[2]]
     }
 
-    return(attr_names)
+    attr_names
   }
 )
 
 
 # get_attrs_values
 setMethod(
-  "get_attrs_values", signature(object = "xml_document"),
-  function(object, path, attr_list = character(length = 0),
-           nodes_ids = NULL) {
-    sel_values <- NULL
-
+  "get_attrs_values",
+  signature(object = "xml_document"),
+  function(object, path, attr_list = character(length = 0), nodes_ids = NULL) {
     # getting attributes values from doc
     attr_values <- get_attrs(object, path)
 
     # no attributes for the query
     if (base::is.null(attr_values)) {
-      return(sel_values)
+      return()
     }
 
     # selecting outputs
@@ -213,7 +226,6 @@ setMethod(
       return(attr_values)
     }
 
-
     # finding existing attr names in path
     sel <- is.element(colnames(attr_values), attr_list)
 
@@ -221,7 +233,8 @@ setMethod(
       # not any given attr_list names exist in path
       if (object@warn) {
         warning(paste(
-          "Not any given attribute name exist in ", path,
+          "Not any given attribute name exist in ",
+          path,
           "aborting !"
         ))
         return()
@@ -248,18 +261,19 @@ setMethod(
       if (max(nodes_ids) <= dim(sel_values)[1]) {
         sel_values <- sel_values[nodes_ids, ]
       } else {
-        stop("Subscript out of range, check ids !")
+        warning("Subscript out of range, check ids !")
+        return(NULL)
       }
     }
-
-    return(sel_values)
+    sel_values
   }
 )
 
 
-# factoriser avec get_attrs!! + getNode(object,path,kind)
+# TODO: factoriser avec get_attrs!! + getNode(object,path,kind)
 setMethod(
-  "get_values", signature(object = "xml_document"),
+  "get_values",
+  signature(object = "xml_document"),
   function(object, path, nodes_ids = NULL) {
     node_set <- get_nodes(object, path)
 
@@ -270,26 +284,27 @@ setMethod(
       return(invisible())
     }
 
-
     if (!base::is.null(nodes_ids)) {
       if (max(nodes_ids) <= nodes_nb) {
         node_set <- node_set[nodes_ids]
       } else {
-        stop("Subscript out of range, check ids !")
+        warning("Subscript out of range, check ids !")
+        return()
       }
     }
 
     # Getting values from the node_set
     val_list <- unlist(lapply(node_set, function(x) XML::xmlValue(x)))
 
-    return(val_list)
+    val_list
   }
 )
 
 
 # add_attrs
 setMethod(
-  "add_attrs", signature(object = "xml_document"),
+  "add_attrs",
+  signature(object = "xml_document"),
   function(object, path, named_vector) {
     # add not is nullnull node_set !!!!
     if (!base::is.null(names(named_vector))) {
@@ -304,7 +319,8 @@ setMethod(
 # delAttrs
 # TODO: to remove all attrs !!!!!!!!!
 setMethod(
-  "remove_attrs", signature(object = "xml_document"),
+  "remove_attrs",
+  signature(object = "xml_document"),
   function(object, path, attr_names) {
     # add not base::is.null node_set !!!!
     if (!base::is.null(attr_names)) {
@@ -322,7 +338,8 @@ setMethod(
 #
 # TODO : same code as set_values,
 setMethod(
-  "set_attrs_values", signature(object = "xml_document"),
+  "set_attrs_values",
+  signature(object = "xml_document"),
   function(object, path, attr_name, values_list, nodes_ids = NULL) {
     node_set <- get_nodes(object, path)
     if (base::is.null(node_set)) {
@@ -340,7 +357,11 @@ setMethod(
     }
     values_nb <- length(values_list)
     if (values_nb != nodes_nb) {
-      stop("Values number is not consistent with nodes number !")
+      warning(
+        "Values number is not consistent with nodes number !",
+        " Aborting !"
+      )
+      return(invisible())
     }
     for (i in 1:nodes_nb) {
       value <- values_list[[i]]
@@ -352,7 +373,8 @@ setMethod(
 
 # set_values
 setMethod(
-  "set_values", signature(object = "xml_document"),
+  "set_values",
+  signature(object = "xml_document"),
   function(object, path, values_list, nodes_ids = NULL) {
     node_set <- get_nodes(object, path)
 
@@ -366,14 +388,17 @@ setMethod(
 
     nodes_nb <- length(node_set)
 
-
     if (length(values_list) == 1) {
       values_list <- rep(values_list, nodes_nb)
     }
     values_nb <- length(values_list)
 
     if (values_nb != nodes_nb) {
-      stop("Values number is not consistent with nodes number to be modified !")
+      warning(
+        "Values number is not consistent with nodes number to be modified !",
+        " Aborting !"
+      )
+      return(invisible())
     }
 
     for (i in 1:nodes_nb) {
@@ -388,7 +413,8 @@ setMethod(
 
 # addNodes
 setMethod(
-  "add_nodes", signature(object = "xml_document"),
+  "add_nodes",
+  signature(object = "xml_document"),
   function(object, nodes_to_add, parent_path = NULL) {
     # parent node is root node
     if (base::is.null(parent_path)) {
@@ -417,7 +443,8 @@ setMethod(
 
 # removeNodes
 setMethod(
-  "del_nodes", signature(object = "xml_document"),
+  "del_nodes",
+  signature(object = "xml_document"),
   function(object, path) {
     node_set <- get_nodes(object, path)
 
@@ -432,24 +459,43 @@ setMethod(
 
 # other methods
 setMethod(
-  "load_content", signature(object = "xml_document"),
+  "load_content",
+  signature(object = "xml_document"),
   function(object) {
+    # getting file path
+    # and checking if file exists
+    if (!exist(object)) {
+      set_content(object) <- XML::newXMLDoc()
+      return(object)
+    }
+    # loading xml content
+    ret <- try(
+      set_content(object) <- XML::xmlParse(get_path(object)),
+      silent = TRUE
+    )
+    if (methods::is(ret, "try-error")) {
+      set_content(object) <- XML::newXMLDoc()
+      if (object@warn) {
+        warning(paste("Error loading xml file:", object@name))
+      }
+    }
 
-    set_content(object) <- XML::xmlParse(get_path(object))
-    return(object)
+    object
   }
 )
 
 
 setMethod(
-  "is_loaded", signature(object = "xml_document"),
+  "is_loaded",
+  signature(object = "xml_document"),
   function(object) {
-    return(methods::is(object@content, "XMLInternalDocument"))
+    methods::is(object@content, "XMLInternalDocument")
   }
 )
 
 setMethod(
-  "is.xml_document", signature(object = "ANY"),
+  "is.xml_document",
+  signature(object = "ANY"),
   function(object) {
     if (methods::is(object, "xml_document")) {
       return(TRUE)
@@ -462,7 +508,8 @@ setMethod(
 
 # save method
 setMethod(
-  "save_xml_doc", signature(object = "xml_document"),
+  "save_xml_doc",
+  signature(object = "xml_document"),
   function(object, xml_path) {
     if (is_loaded(object)) {
       write(XML::saveXML(object@content), xml_path)
@@ -472,7 +519,8 @@ setMethod(
 
 # clone method
 setMethod(
-  "clone_xml_doc", signature(object = "xml_document"),
+  "clone_xml_doc",
+  signature(object = "xml_document"),
   function(object) {
     if (!is_loaded(object)) {
       return(NULL)
@@ -480,13 +528,14 @@ setMethod(
 
     set_content(object) <- XML::xmlClone(get_content(object))
 
-    return(object)
+    object
   }
 )
 
 # delete object method
 setMethod(
-  "delete", signature(object = "xml_document"),
+  "delete",
+  signature(object = "xml_document"),
   function(object) {
     # freeing object @content slot (external pointer)
     # and deleting xml_document object
@@ -494,6 +543,5 @@ setMethod(
 
     rm(object)
     invisible(gc(verbose = FALSE))
-
   }
 )
