@@ -1,4 +1,3 @@
-
 context("Generating xml general parameters files")
 
 gen_general_param_xml(out_dir = tempdir())
@@ -14,8 +13,10 @@ test_that("latest version", {
 
 
 test_that("other version", {
-  expect_no_error(gen_general_param_xml(out_dir = tempdir(),
-                                        stics_version = "V10.0",
-                                        overwrite = TRUE))
+  expect_no_error(gen_general_param_xml(
+    out_dir = tempdir(),
+    stics_version = "V10.0",
+    overwrite = TRUE
+  ))
   expect_true(all(file.exists(file.path(tempdir(), files))))
 })
