@@ -1,5 +1,3 @@
-library(SticsRFiles)
-
 stics_version <- get_stics_versions_compat()$latest_version
 version_num <- get_version_num()
 
@@ -12,6 +10,7 @@ test_that("Create a xml station file", {
   expect_error(gen_paramsti(
     file.path(workspace_path, "xxx"),
     c("par1", "par2"),
-    c(1, 2)))
+    c(1, 2)
+  ))
   expect_false(gen_paramsti(workspace_path, c("par1", "par2"), c(1, 2, 3)))
 })
