@@ -1,5 +1,3 @@
-library(SticsRFiles)
-
 context("Creating a varmod file to latest version")
 
 out_dir <- file.path(tempdir(), "varmod")
@@ -16,8 +14,11 @@ gen_varmod(out_dir, "hauteur", append = TRUE)
 
 test_that("Add a new variable", {
   expect_true(
-    grep(pattern = "hauteur",
-         readLines(file.path(out_dir, "var.mod"))) > 0)
+    grep(
+      pattern = "hauteur",
+      readLines(file.path(out_dir, "var.mod"))
+    ) >
+      0
+  )
   expect_warning(gen_varmod(out_dir, ""))
-
-  })
+})
