@@ -1,5 +1,3 @@
-library(SticsRFiles)
-
 stics_version <- get_stics_versions_compat()$latest_version
 version_num <- get_version_num()
 
@@ -10,7 +8,11 @@ get_option_choice_param_values(xml_path, "codetemp", "2")
 test_that("Option choice", {
   expect_equal(
     length(
-      unlist(get_option_choice_param_values(xml_path, "codetemp", "2"),
-             use.names = FALSE)),
-    14)
-  })
+      unlist(
+        get_option_choice_param_values(xml_path, "codetemp", "2"),
+        use.names = FALSE
+      )
+    ),
+    14
+  )
+})
