@@ -1,5 +1,3 @@
-library(SticsRFiles)
-
 stics_version <- get_stics_versions_compat()$latest_version
 
 xml_path <- file.path(
@@ -10,7 +8,9 @@ context("Getting gen param values")
 
 test_that("all values from a single node", {
   expect_equal(
-    unname(unlist(get_param_xml(xml_path, c("masvolcx", "hcccx"),
+    unname(unlist(get_param_xml(
+      xml_path,
+      c("masvolcx", "hcccx"),
       select = "Lutetian Brackish marl and limestone"
     ))),
     c(2.3, 5)
@@ -19,9 +19,15 @@ test_that("all values from a single node", {
 
 test_that("getting values from choice param", {
   expect_equal(
-    unname(unlist(get_param_xml(xml_path, c(
-      "tnitmin", "tnitopt", "tnitopt2",
-      "tnitmax"
-    )))), c(5, 30, 35, 58)
+    unname(unlist(get_param_xml(
+      xml_path,
+      c(
+        "tnitmin",
+        "tnitopt",
+        "tnitopt2",
+        "tnitmax"
+      )
+    ))),
+    c(5, 30, 35, 58)
   )
 })
